@@ -84,7 +84,7 @@ var folderGreen = new Image(32,32);
 folderGreen.src='/style/Crystal/32/html-menu-treeview/folder_green.png';
 var folderViolet = new Image(32,32);
 folderViolet.src='/style/Crystal/32/html-menu-treeview/folder_violet.png';
-var folderYellowClosed = naew Image(32,32);
+var folderYellowClosed = new Image(32,32);
 folderYellowClosed.src='/style/Crystal/32/html-menu-treeview/folder_yellow.png';
 var folderOrangeClosed = new Image(32,32);
 folderOrangeClosed.src='/style/Crystal/32/html-menu-treeview/folder_orange.png';
